@@ -18,13 +18,15 @@ module Gem
     end
   end
 
-  def self.platform_defaults
-    return {
-        'install' => '--env-shebang',
-        'update' => '--env-shebang',
-        'setup' => '--env-shebang',
-        'pristine' => '--env-shebang'
-    }
+  unless RbConfig::CONFIG['host_os'].match?(/linux/)
+    def self.platform_defaults
+      return {
+          'install' => '--env-shebang',
+          'update' => '--env-shebang',
+          'setup' => '--env-shebang',
+          'pristine' => '--env-shebang'
+      }
+    end
   end
 
   # Default home directory path to be used if an alternate value is not
@@ -99,7 +101,13 @@ begin
 rescue LoadError
 end
 
-begin
-  require 'jar_install_post_install_hook'
-rescue LoadError
+if defined?(JRUBY_VERSION) && Gem.post_install_hooks.empty?
+  Gem.post_install do |gem_installer|
+    unless (ENV['JARS_SKIP'] || ENV_JAVA['jars.skip']) == 'true'
+      require 'jars/installer'
+      jars = Jars::Installer.new(gem_installer.spec)
+      jars.ruby_maven_install_options = gem_installer.options || {}
+      jars.vendor_jars
+    end
+  end
 end
